@@ -662,19 +662,6 @@ on_dock_window_unmapped (GtkWidget *dock_window, Git *plugin)
 	                                   plugin->command_bar_window, NULL);
 }
 
-static void
-on_shell_exiting (AnjutaShell *shell, Git *plugin)
-{
-	g_signal_handlers_disconnect_by_func (G_OBJECT (plugin->dock_window),
-	                                      G_CALLBACK (on_dock_window_mapped),
-	                                      plugin);
-
-	g_signal_handlers_disconnect_by_func (G_OBJECT (plugin->dock_window),
-	                                      G_CALLBACK (on_dock_window_unmapped),
-	                                      plugin);
-}
-
-
 static gboolean
 git_activate_plugin (AnjutaPlugin *plugin)
 {
@@ -843,11 +830,7 @@ git_activate_plugin (AnjutaPlugin *plugin)
 														   on_editor_removed,
 														   NULL);
 
-	g_signal_connect (G_OBJECT (plugin->shell), "exiting",
-	                  G_CALLBACK (on_shell_exiting),
-	                  git_plugin);
-	
-	
+
 	/* Git needs a working directory to work with; it can't take full paths,
 	 * so make sure that Git can't be used if there's no project opened. */
 	if (!git_plugin->project_root_directory)
@@ -863,10 +846,8 @@ static gboolean
 git_deactivate_plugin (AnjutaPlugin *plugin)
 {
 	Git *git_plugin;
-	AnjutaStatus *status;
 	
 	git_plugin = ANJUTA_PLUGIN_GIT (plugin);
-	status = anjuta_shell_get_status (plugin->shell, NULL);
 	
 	DEBUG_PRINT ("%s", "Git: Dectivating Git plugin.\n");
 	
@@ -883,10 +864,6 @@ git_deactivate_plugin (AnjutaPlugin *plugin)
 	                                      G_CALLBACK (on_dock_window_unmapped),
 	                                      plugin);
 
-	g_signal_handlers_disconnect_by_func (G_OBJECT (plugin->shell),
-	                                      G_CALLBACK (on_shell_exiting),
-	                                      git_plugin);
-	
 	anjuta_shell_remove_widget (plugin->shell, git_plugin->command_bar_window, NULL);
 	anjuta_shell_remove_widget (plugin->shell, git_plugin->dock_window, NULL);
 
