@@ -329,6 +329,18 @@ initialize_indentation_params (IndentCPlugin *plugin)
     }
 }
 
+static gboolean
+language_is_supported (const gchar* language)
+{
+    return (language &&
+            (g_str_equal (language, "C") ||
+             g_str_equal (language, "C++") ||
+             g_str_equal (language, "Vala") ||
+             g_str_equal (language, "Java") ||
+             g_str_equal (language, "JavaScript") ||
+             g_str_equal (language, "IDL")));
+}
+
 /* Enable/Disable language-support */
 static void
 install_support (IndentCPlugin *lang_plugin)
@@ -350,12 +362,7 @@ install_support (IndentCPlugin *lang_plugin)
     DEBUG_PRINT("Indentation support installed for: %s",
                 lang_plugin->current_language);
 
-    if (lang_plugin->current_language &&
-        (g_str_equal (lang_plugin->current_language, "C")
-        || g_str_equal (lang_plugin->current_language, "C++")
-        || g_str_equal (lang_plugin->current_language, "Vala")
-        || g_str_equal (lang_plugin->current_language, "Java")
-        || g_str_equal (lang_plugin->current_language, "JavaScript")))
+    if (language_is_supported (lang_plugin->current_language))
     {
         g_signal_connect (lang_plugin->current_editor,
                           "char-added",
@@ -381,12 +388,7 @@ uninstall_support (IndentCPlugin *lang_plugin)
     if (!lang_plugin->support_installed)
         return;
 
-    if (lang_plugin->current_language &&
-        (g_str_equal (lang_plugin->current_language, "C")
-        || g_str_equal (lang_plugin->current_language, "C++")
-        || g_str_equal (lang_plugin->current_language, "Vala")
-        || g_str_equal (lang_plugin->current_language, "Java")
-        || g_str_equal (lang_plugin->current_language, "JavaScript")))
+    if (language_is_supported (lang_plugin->current_language))
     {
         g_signal_handlers_disconnect_by_func (lang_plugin->current_editor,
                                     G_CALLBACK (cpp_java_indentation_char_added),
